==> numpoly-0.1.17-py2.py3-none-any.whl: numpoly/array_function/__init__.py <==
"""Collection of numpy wrapper functions."""
from .common import ARRAY_FUNCTIONS

from .absolute import absolute as abs, absolute
from .add import add
from .any import any
from .all import all
from .allclose import allclose
from .apply_along_axis import apply_along_axis
from .apply_over_axes import apply_over_axes
from .around import around as round, around
from .array_repr import array_repr
from .array_split import array_split
from .array_str import array_str
from .atleast_1d import atleast_1d
from .atleast_2d import atleast_2d
from .atleast_3d import atleast_3d
from .broadcast_arrays import broadcast_arrays
from .ceil import ceil
from .choose import choose
from .common_type import common_type
from .concatenate import concatenate
from .count_nonzero import count_nonzero
from .cumsum import cumsum
from .divide import divide
from .dsplit import dsplit
from .dstack import dstack
from .equal import equal
from .expand_dims import expand_dims
from .floor import floor
from .floor_divide import floor_divide
from .hstack import hstack
from .hsplit import hsplit
from .inner import inner
from .isclose import isclose
from .isfinite import isfinite
from .logical_and import logical_and
from .logical_or import logical_or
from .matmul import matmul
from .mean import mean
from .moveaxis import moveaxis
from .multiply import multiply
from .negative import negative
from .nonzero import nonzero
from .not_equal import not_equal
from .outer import outer
from .positive import positive
from .power import power
from .prod import prod
from .repeat import repeat
from .reshape import reshape
from .rint import rint
from .split import split
from .square import square
from .stack import stack
from .subtract import subtract
from .sum import sum
from .tile import tile
from .transpose import transpose
from .vsplit import vsplit
from .vstack import vstack

==> numpoly-0.2.0-py2.py3-none-any.whl: numpoly/array_function/__init__.py <==
"""Collection of numpy wrapper functions."""
from .absolute import absolute as abs, absolute
from .add import add
from .any import any
from .all import all
from .allclose import allclose
from .apply_along_axis import apply_along_axis
from .apply_over_axes import apply_over_axes
from .around import around, around as round, around as round_
from .array_repr import array_repr
from .array_split import array_split
from .array_str import array_str
from .atleast_1d import atleast_1d
from .atleast_2d import atleast_2d
from .atleast_3d import atleast_3d
from .broadcast_arrays import broadcast_arrays
from .ceil import ceil
from .choose import choose
from .common_type import common_type
from .concatenate import concatenate
from .count_nonzero import count_nonzero
from .cumsum import cumsum
from .true_divide import true_divide, true_divide as divide
from .divmod import divmod
from .dsplit import dsplit
from .dstack import dstack
from .equal import equal
from .expand_dims import expand_dims
from .floor import floor
from .floor_divide import floor_divide
from .hstack import hstack
from .hsplit import hsplit
from .inner import inner
from .isclose import isclose
from .isfinite import isfinite
from .logical_and import logical_and
from .logical_or import logical_or
from .matmul import matmul
from .mean import mean
from .moveaxis import moveaxis
from .multiply import multiply
from .negative import negative
from .nonzero import nonzero
from .not_equal import not_equal
from .outer import outer
from .positive import positive
from .power import power
from .prod import prod
from .remainder import remainder as mod, remainder
from .repeat import repeat
from .reshape import reshape
from .rint import rint
from .split import split
from .square import square
from .stack import stack
from .subtract import subtract
from .sum import sum
from .tile import tile
from .transpose import transpose
from .vsplit import vsplit
from .vstack import vstack
from .where import where
from .zeros import zeros
